math.randomseed(os.time())
math.random()

function love.load()
	stage = {w=love.graphics.getWidth(), h=love.graphics.getHeight()}
	
	vertices = {}
	nVert = 6
	for i=1, nVert do
		local vert = {}
		vert.offset = 0.0
		vert.angle = 0.0
		table.insert(vertices, vert)
	end

	cur_time = 0

	n_origin = {x=math.random()*65536-32768, y=math.random()*65536-32768}

	mode = 0
end

function love.keypressed(key)
	if key == "tab" then
		mode = (mode + 1)%3
		print(mode)
	end
end

function love.update(dt)
	cur_time = cur_time + dt
	
	for i, v in ipairs(vertices) do
		if mode ~= 2 then
			v.offset = (love.math.noise((i-n_origin.x)/2, cur_time/2)*2-1)
		else
			v.offset = 0.0
		end
		if mode ~= 1 then
			v.angle = (love.math.noise((i-n_origin.x)/2-100, cur_time/2)*2-1)
		else
			v.angle = 0.0
		end
	end
end

function love.draw()
	love.graphics.setColor(255, 255, 255)

	local polyVert = {}
	for i, v in ipairs(vertices) do
		local res = {}
		local m = (200+100*v.offset)
		local a = 2*math.pi/6
		res.x = m*math.cos(v.angle/a*0.5 + a*i)
		res.y = m*math.sin(v.angle/a*0.5 + a*i)
		table.insert(polyVert, res.x+stage.w/2)
		table.insert(polyVert, res.y+stage.h/2)
	end

	love.graphics.polygon("line", polyVert)
end

-- returns a fractal noise value in the range [-1.0, 1.0]
function genFractalNoise2(x, y, iter, factor, f)
	val = love.math.noise(x, y)*2-1
	f = f or 2
	iter = iter or 1
	factor = factor or 0.5
	local n = 0
	while n < iter-1 do
		val = val + (love.math.noise(x*n^f, y*n^f)*2-1)*factor^n
		n = n + 1
	end
	return math.max(math.min(val, 1.0), -1.0)
end

-- returns a fractal noise value in the range [-1.0, 1.0]
function genFractalNoise3(x, y, z, iter, factor, f)
	val = love.math.noise(x, y, z)*2-1
	f = f or 2
	local n = 0
	while n < iter-1 do
		val = val + (love.math.noise(x*n^f, y*n^f, z*n^f)*2-1)*factor^n
		n = n + 1
	end
	return math.max(math.min(val, 1.0), -1.0)
end